@@ -39,6 +39,13 @@ $(function() {
                     if (data.content.hasOwnProperty("l_errorcode0")) {
                         exibeMensagemErro(data.content["l_errorcode0"], data.content["l_shortmessage0"] + " - " + data.content["l_longmessage0"]);
                     }
+                    else if (data.status == 404) {
+                        var fatal = false;
+                        if (data.content.hasOwnProperty("fatal")) {
+                            fatal = data.content.fatal;
+                        }
+                        exibeMensagemErro(data.status, data.content.mensagem, fatal);
+                    }
                     else if (data.content.hasOwnProperty("erro")) {
                         exibeMensagemErro(data.status, data.content.erro);
                     }
@@ -62,12 +69,16 @@ $(function() {
         window.location = url;
     });
 
-    function exibeMensagemErro(status, mensagem) {
+    function exibeMensagemErro(status, mensagem, fatal) {
         $payPalMensagem.find(".msg-warning").hide();
         $payPalMensagem.toggleClass("alert-message-warning alert-message-danger");
         var $errorMessage = $("#errorMessage");
         $errorMessage.text(status + ": " + mensagem);
         $payPalMensagem.find(".msg-danger").show();
+        if (fatal) {
+            $(".pagar").remove();
+            $(".click").remove();
+        }
     }
 
     function exibeMensagemSucesso(situacao) {
@@ -88,19 +99,8 @@ $(function() {
     var pedidoAguardandoPagamento = '{{ pedido.situacao_id }}' == '2' || '{{ pedido.situacao_id }}' == '3';
 
     if (window.location.search != "" && window.location.search.indexOf("failure") > -1) {
-//        if (window.location.search.indexOf("erro_retorno") > -1) {
-//            exibeMensagemErro(500, "Pagamento não processado!");
-//            $(".complemento").show();
-//        }
-//        else {
         exibeMensagemErro(500, "Pagamento cancelado no PayPal!");
-//        }
     }
-//    else if (window.location.search != "" && (window.location.search.indexOf("success") > -1 && !pedidoPago)) {
-//        $("#aguarde").hide();
-//        $("#finalizando").show();
-//        enviaPagamento("GetExpressCheckoutDetails");
-//    }
     else if (window.location.search != "" && window.location.search.indexOf("success") > -1 || pedidoPago) {
         exibeMensagemSucesso("pago");
     }
